// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KGUIADDONS_VERSION_H
#define KGUIADDONS_VERSION_H

#define KGUIADDONS_VERSION_STRING "5.98.0"
#define KGUIADDONS_VERSION_MAJOR 5
#define KGUIADDONS_VERSION_MINOR 98
#define KGUIADDONS_VERSION_PATCH 0
#define KGUIADDONS_VERSION ((5<<16)|(98<<8)|(0))

#endif
